pub struct Geomcdf;Expand description
Cummulative geometric probability function.
Returns the probability of the first success of an event occurring on or before the nth
trial, where the probability of success on a single trial is p.
Implementations