pub struct Geompdf;Expand description
Geometric probability function.
Returns the probability of the first success of an event occurring on the nth trial, where the
probability of success on a single trial is p.
Implementations