pub struct Normcdf;Expand description
Normal cumulative distribution function.
Returns the probability that a random variable, chosen from a normal distribution with mean m
and standard deviation s, will be between a and b, inclusive.
Implementations