Module sequence

Module sequence 

Functions to determine the specified term of particular sequences.

Structs

Fib
Returns the nth term of the Fibonacci sequence, using a fast doubling algorithm with O(log n) complexity, extended to support negative indices.