FormatOptionsBuilder

Struct FormatOptionsBuilder 

pub struct FormatOptionsBuilder(/* private fields */);
Helper struct to build a FormatOptions struct.

Implementations

Source

impl FormatOptionsBuilder

pub fn new() -> Self

Creates a new builder with the default options.

pub fn number(self, number: NumberFormat) -> Self

Sets the number format. See NumberFormat for more information.

pub fn scientific(self, scientific: Scientific) -> Self

Sets the scientific notation suffix. See Scientific for more information.

pub fn precision(self, precision: Option<usize>) -> Self

Sets the maximum number of digits to show. If None, the number is formatted with full precision. See FormatOptions::precision for more information.

pub fn separators(self, separators: Separator) -> Self

Sets whether to display separators for large numbers. See Separator for more information.

pub fn show_refs(self, show_refs: ShowRefs) -> Self

Sets whether to print addresses of reference types, such as lists. See ShowRefs for more information.

pub fn build(self) -> FormatOptions

Builds the FormatOptions struct.