pub struct User {
pub index: usize,
pub captures: HashSet<usize>,
pub environment: HashMap<usize, Value>,
}Expand description
A user-defined function.
Fields
index: usizeThe index of the function’s chunk.
TODO: comparing index is not enough to compare two functions
captures: HashSet<usize>The variables captured by the function from the environment.
This is determined at compile time.
environment: HashMap<usize, Value>The values of the variables in the function’s environment at the time of the function’s creation.
This is determined at runtime.
Implementations