pub struct Poisscdf;Expand description
Cummulative poisson probability function.
Returns the probability of k or fewer events occurring in an arbitrary time interval, where
the mean number of occurrences of the event in the time interval is l.
Implementations