Module sequence
cas_
compute
0.2.0
Module sequence
Module Items
Structs
In cas_
compute::
funcs
cas_compute
::
funcs
Module
sequence
Functions to determine the specified term of particular sequences.
Structs

Fib
Returns the
n
th term of the Fibonacci sequence, using a fast doubling algorithm with
O(log n)
complexity, extended to support negative indices.