pub enum Function {
User(User),
Builtin(&'static dyn Builtin),
}Expand description
A function.
Functions are treated as values just like any other value in cas-rs; they can be stored
in variables, passed as arguments to other functions, and returned from functions.
Variants
User(User)
A user-defined function.
The inner value is a usize that represents the index of the function’s chunk.
Builtin(&'static dyn Builtin)
A built-in function.